==> qmmp_0.8.2.orig.tar.bz2: qmmp-0.8.2/src/plugins/Input/flac/translations/flac_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="60"/>
        <source>FLAC Plugin</source>
        <translation>FLAC Eklentisi</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="62"/>
        <source>FLAC Files</source>
        <translation>FLAC Dosyaları</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="200"/>
        <source>About FLAC Audio Plugin</source>
        <translation>FLAC Ses Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="201"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Qmmp FLAC Ses Eklentisi</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="202"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="80"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="81"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="81"/>
        <source>Hz</source>
        <translation type="unfinished">Hz</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>kbps</source>
        <translation type="unfinished">kbps</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>KB</source>
        <translation type="unfinished">KB</translation>
    </message>
</context>
</TS>

==> qmmp-0.8.4.tar.bz2: qmmp-0.8.4/src/plugins/Input/flac/translations/flac_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="60"/>
        <source>FLAC Plugin</source>
        <translation>FLAC Eklentisi</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="62"/>
        <source>FLAC Files</source>
        <translation>FLAC Dosyaları</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="200"/>
        <source>About FLAC Audio Plugin</source>
        <translation>FLAC Ses Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="201"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Qmmp FLAC Ses Eklentisi</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="202"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="80"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="81"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="81"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
